@@ -769,7 +769,7 @@ class PyQuery(list):
                     tag.set(key, value)
         elif value is no_default:
             return self[0].get(attr)
-        elif value is None or value == '':
+        elif value is None:
             return self.remove_attr(attr)
         else:
             for tag in self:
@@ -971,13 +971,21 @@ class PyQuery(list):
             if tag.tag == 'textarea':
                 return self._copy(tag).text()
             # <select>
-            if tag.tag == 'select':
+            elif tag.tag == 'select':
                 selected_option = self._copy(tag)('option[selected]:last')
                 if selected_option:
                     return selected_option.attr('value')
-                return None
+                else:
+                    return self._copy(tag)('option').attr('value')
+            # <input type="checkbox"> or <input type="radio">
+            elif self.is_(':checkbox,:radio'):
+                val = self._copy(tag).attr('value')
+                if val is None:
+                    return 'on'
+                else:
+                    return val
             # <input> and everything else.
-            return self._copy(tag).attr('value') or None
+            return self._copy(tag).attr('value') or ''
 
         def _set_value(pq, value):
             for tag in pq:
